@@ -21,11 +21,11 @@
 #ifndef vte_vtedraw_h_included
 #define vte_vtedraw_h_included
 
-#ident "$Id: vtedraw.h,v 1.7 2003/05/28 21:53:59 nalin Exp $"
 
 #include <glib.h>
 #include <gtk/gtk.h>
 #include "vtebg.h"
+#include "vte.h"
 
 G_BEGIN_DECLS
 
@@ -66,10 +66,13 @@ struct _vte_draw_impl {
 				     double saturation);
 	gboolean requires_repaint;
 	void (*clear)(struct _vte_draw *, gint, gint, gint, gint);
-	void (*set_text_font)(struct _vte_draw *, const PangoFontDescription *);
+	void (*set_text_font)(struct _vte_draw *,
+			      const PangoFontDescription *,
+			      VteTerminalAntiAlias);
 	int (*get_text_width)(struct _vte_draw *);
 	int (*get_text_height)(struct _vte_draw *);
 	int (*get_text_ascent)(struct _vte_draw *);
+	int (*get_char_width)(struct _vte_draw *, gunichar c, int columns);
 	gboolean (*get_using_fontconfig)(struct _vte_draw *);
 	void (*draw_text)(struct _vte_draw *,
 			  struct _vte_draw_text_request *, gsize,
@@ -125,11 +128,13 @@ void _vte_draw_clear(struct _vte_draw *draw,
 
 /* Set the font which will be used to draw text. */
 void _vte_draw_set_text_font(struct _vte_draw *draw,
-			     const PangoFontDescription *fontdesc);
+			     const PangoFontDescription *fontdesc,
+			     VteTerminalAntiAlias anti_alias);
 /* Read font metrics. */
 int _vte_draw_get_text_width(struct _vte_draw *draw);
 int _vte_draw_get_text_height(struct _vte_draw *draw);
 int _vte_draw_get_text_ascent(struct _vte_draw *draw);
+int _vte_draw_get_char_width(struct _vte_draw *draw, gunichar c, int columns);
 gboolean _vte_draw_get_using_fontconfig(struct _vte_draw *draw);
 
 /* Draw text or rectangles. */
